@@ -35,6 +35,8 @@ class ForgeRpc:
         self.get_net_info = self.chain.get_net_info
         self.get_validators_info = self.chain.get_validators_info
         self.get_config = self.chain.get_config
+        self.multisig = self.chain.multisig
+        self.get_asset_address = self.chain.get_asset_address
 
         self.event = RpcEvent(self.chan)
         self.subscribe = self.event.subscribe
@@ -59,19 +61,63 @@ class ForgeRpc:
         self.list_wallet = self.wallet.list_wallet
         self.declare_node = self.wallet.declare_node
 
-    def send_itx(self, type_url, itx, wallet, token=''):
+    def send_itx(self, type_url, itx, wallet, token):
         encoded_itx = utils.encode_to_any(type_url, itx)
-        nonce = self.get_nonce(wallet.address)
-        tx_builder = self.create_tx(
-            encoded_itx, wallet.address, nonce,
-            wallet, token,
+        tx = self.create_tx(
+            itx=encoded_itx, from_address=wallet.address,
+            wallet=wallet, token=token,
         )
-        return self.send_tx(tx_builder.tx)
+        return self.send_tx(tx.tx)
 
-    def get_nonce(self, address):
+    def create_asset(self, type_url, asset, wallet, token):
+        encoded_asset = utils.encode_to_any(type_url, asset)
+        create_asset_itx = utils.encode_to_any(
+            type_url='fg:t:create_asset',
+            data=protos.CreateAssetTx(data=encoded_asset),
+        )
+        tx = self.create_tx(
+            create_asset_itx, wallet.address, wallet, token,
+        )
+        return self.send_tx(tx.tx)
+
+    def update_asset(self, type_url, address, asset, wallet, token):
+        encoded_asset = utils.encode_to_any(type_url, asset)
+        update_asset_itx = utils.encode_to_any(
+            type_url='fg:t:update_asset',
+            data=protos.UpdateAssetTx(
+                address=address,
+                data=encoded_asset,
+            ),
+        )
+        tx = self.create_tx(
+            update_asset_itx, wallet.address, wallet, token,
+        )
+        return self.send_tx(tx.tx)
+
+    def get_single_account_state(self, address):
         accounts = self.get_account_state({'address': address})
         account = next(accounts)
-        if not account:
-            self.logger.error("Account doesn't exist!")
+        if utils.is_proto_empty(account):
+            return None
         else:
-            return account.state.nonce
+            return account.state
+
+    def get_single_tx_info(self, hash):
+        infos = self.get_tx(hash)
+        info = next(infos)
+        if utils.is_proto_empty(info):
+            return None
+        else:
+            return info.info
+
+    def get_single_asset_state(self, address):
+        assets = self.get_asset_state({'address': address})
+        asset = next(assets)
+        if utils.is_proto_empty(asset):
+            return None
+        else:
+            return asset.state
+
+    def get_nonce(self, address):
+        account = self.get_single_account_state(address)
+        return account.nonce
